@@ -2,21 +2,14 @@
 import com.beust.kobalt.TaskResult
 import com.beust.kobalt.api.Project
 import com.beust.kobalt.api.annotation.Task
-import com.beust.kobalt.plugin.java.javaProject
 import com.beust.kobalt.plugin.packaging.assemble
-import com.beust.kobalt.plugins
+import com.beust.kobalt.project
 import com.beust.kobalt.test
 import java.io.File
 
-//import com.beust.kobalt.plugin.linecount.*
+val VERSION = "6.9.11-SNAPSHOT"
 
-val VERSION = "6.9.10-SNAPSHOT"
-
-//val plugins = plugins("com.beust.kobalt:kobalt-line-count:0.17")
-
-val p = javaProject {
-
-//    line
+val p = project {
     name = "testng"
     group = "org.testng"
     artifactId = name
@@ -46,12 +39,13 @@ val p = javaProject {
 
     assemble {
         jar {
+            fatJar = true
         }
     }
 }
 
 @Task(name = "createVersion", runBefore = arrayOf("compile"), runAfter = arrayOf("clean"), description = "")
-fun taskCreateVersion(project: Project) : TaskResult {
+fun taskCreateVersion(project: Project): TaskResult {
     val path = "org/testng/internal"
     with(arrayListOf<String>()) {
         File("src/main/resources/$path/VersionTemplateJava").forEachLine {
@@ -61,4 +55,3 @@ fun taskCreateVersion(project: Project) : TaskResult {
     }
     return TaskResult()
 }
-
