@@ -297,7 +297,7 @@ public class TestRunner
     Class<? extends ITestNGListenerFactory> listenerFactoryClass = null;
 
     for (IClass cls : getTestClasses()) {
-      Class<? extends ITestNGListenerFactory> realClass = cls.getRealClass();
+      Class<?> realClass = cls.getRealClass();
       ListenerHolder listenerHolder = findAllListeners(realClass);
       if (listenerFactoryClass == null) {
         listenerFactoryClass = listenerHolder.listenerFactoryClass;
@@ -331,44 +331,12 @@ public class TestRunner
 
     // Instantiate all the listeners
     for (Class<? extends ITestNGListener> c : listenerClasses) {
-      Object listener = listenerFactory != null ? listenerFactory.createListener(c) : null;
+      ITestNGListener listener = listenerFactory != null ? listenerFactory.createListener(c) : null;
       if (listener == null) {
         listener = ClassHelper.newInstance(c);
       }
 
-      if (listener instanceof IMethodInterceptor) {
-        m_methodInterceptors.add((IMethodInterceptor) listener);
-      }
-      if (listener instanceof ISuiteListener) {
-        m_suite.addListener((ISuiteListener) listener);
-      }
-      if (listener instanceof IInvokedMethodListener) {
-        m_suite.addListener((ITestNGListener) listener);
-      }
-      if (listener instanceof ITestListener) {
-        // At this point, the field m_testListeners has already been used in the creation
-        addTestListener((ITestListener) listener);
-      }
-      if (listener instanceof IClassListener) {
-        m_classListeners.add((IClassListener) listener);
-      }
-      if (listener instanceof IConfigurationListener) {
-        addConfigurationListener((IConfigurationListener) listener);
-      }
-      if (listener instanceof IReporter) {
-        m_suite.addListener((ITestNGListener) listener);
-      }
-      if (listener instanceof IConfigurable) {
-        m_configuration.setConfigurable((IConfigurable) listener);
-      }
-      if (listener instanceof IHookable) {
-        m_configuration.setHookable((IHookable) listener);
-      }
-      if (listener instanceof IExecutionListener) {
-        IExecutionListener iel = (IExecutionListener) listener;
-        iel.onExecutionStart();
-        m_configuration.addExecutionListener(iel);
-      }
+      addListener(listener);
     }
   }
 
@@ -729,16 +697,12 @@ public class TestRunner
     m_allTestMethods= runMethods.toArray(new ITestNGMethod[runMethods.size()]);
   }
 
-  private static final EnumSet<XmlSuite.ParallelMode> PRIVATE_RUN_PARALLEL_MODES
-      = EnumSet.of(XmlSuite.ParallelMode.METHODS, XmlSuite.ParallelMode.TRUE,
-                   XmlSuite.ParallelMode.CLASSES, XmlSuite.ParallelMode.INSTANCES);
   /**
    * Main method that create a graph of methods and then pass it to the
    * graph executor to run them.
    */
   private void privateRun(XmlTest xmlTest) {
-    XmlSuite.ParallelMode parallelMode = xmlTest.getParallel();
-    boolean parallel = PRIVATE_RUN_PARALLEL_MODES.contains(parallelMode);
+    boolean parallel = xmlTest.getParallel().isParallel();
 
     {
       // parallel
@@ -993,9 +957,6 @@ public class TestRunner
   //
   // Invoke the workers
   //
-  private static final EnumSet<XmlSuite.ParallelMode> WORKERS_PARALLEL_MODES
-      = EnumSet.of(XmlSuite.ParallelMode.METHODS, XmlSuite.ParallelMode.TRUE,
-                   XmlSuite.ParallelMode.CLASSES);
   private void runJUnitWorkers(List<? extends IWorker<ITestNGMethod>> workers) {
       //
       // Sequential run
@@ -1087,7 +1048,7 @@ public class TestRunner
     // giving the impression of parallelism (multiple thread id's) while still running
     // sequentially.
     if (! hasDependencies
-        && getCurrentXmlTest().getParallel() == XmlSuite.ParallelMode.FALSE
+        && getCurrentXmlTest().getParallel() == XmlSuite.ParallelMode.NONE
         && "true".equalsIgnoreCase(getCurrentXmlTest().getPreserveOrder())) {
       // If preserve-order was specified and the class order is A, B
       // create a new set of dependencies where each method of B depends
@@ -1473,26 +1434,63 @@ public class TestRunner
   /////
   // Listeners
   //
+  /**
+   * @deprecated addListener(ITestNGListener) should be used instead
+   */
+  // TODO remove it
+  @Deprecated
   public void addListener(Object listener) {
-    if(listener instanceof ITestListener) {
+    if (listener instanceof ITestNGListener) {
+      addListener((ITestNGListener) listener);
+    }
+  }
+
+  public void addListener(ITestNGListener listener) {
+    // TODO a listener may be added many times if it implements many interfaces
+    if (listener instanceof IMethodInterceptor) {
+      m_methodInterceptors.add((IMethodInterceptor) listener);
+    }
+    if (listener instanceof ISuiteListener) {
+      m_suite.addListener(listener);
+    }
+    if (listener instanceof IInvokedMethodListener) {
+      m_suite.addListener(listener);
+    }
+    if (listener instanceof ITestListener) {
+      // At this point, the field m_testListeners has already been used in the creation
       addTestListener((ITestListener) listener);
     }
-    if(listener instanceof IConfigurationListener) {
+    if (listener instanceof IClassListener) {
+      m_classListeners.add((IClassListener) listener);
+    }
+    if (listener instanceof IConfigurationListener) {
       addConfigurationListener((IConfigurationListener) listener);
     }
-    if(listener instanceof IClassListener) {
-      addClassListener((IClassListener) listener);
+    if (listener instanceof IReporter) {
+      m_suite.addListener(listener);
+    }
+    if (listener instanceof IConfigurable) {
+      m_configuration.setConfigurable((IConfigurable) listener);
+    }
+    if (listener instanceof IHookable) {
+      m_configuration.setHookable((IHookable) listener);
+    }
+    if (listener instanceof IExecutionListener) {
+      IExecutionListener iel = (IExecutionListener) listener;
+      iel.onExecutionStart();
+      m_configuration.addExecutionListener(iel);
     }
   }
 
+  /**
+   * @deprecated addListener(ITestNGListener) should be used instead
+   */
+  // TODO change public to package visibility
+  @Deprecated
   public void addTestListener(ITestListener il) {
     m_testListeners.add(il);
   }
 
-  public void addClassListener(IClassListener cl) {
-    m_classListeners.add(cl);
-  }
-
   void addConfigurationListener(IConfigurationListener icl) {
     m_configurationListeners.add(icl);
   }
