@@ -173,11 +173,9 @@ public class TestNGContentHandler extends DefaultHandler {
       if (guiceStage != null) {
         m_currentSuite.setGuiceStage(guiceStage);
       }
-      String configFailurePolicy = attributes.getValue("configfailurepolicy");
+      XmlSuite.FailurePolicy configFailurePolicy = XmlSuite.FailurePolicy.getValidPolicy(attributes.getValue("configfailurepolicy"));
       if (null != configFailurePolicy) {
-        if (XmlSuite.SKIP.equals(configFailurePolicy) || XmlSuite.CONTINUE.equals(configFailurePolicy)) {
-          m_currentSuite.setConfigFailurePolicy(configFailurePolicy);
-        }
+        m_currentSuite.setConfigFailurePolicy(configFailurePolicy);
       }
       String groupByInstances = attributes.getValue("group-by-instances");
       if (groupByInstances!= null) {
@@ -385,7 +383,8 @@ public class TestNGContentHandler extends DefaultHandler {
     }
     else {
       if (null != m_currentPackages) {
-        switch(m_locations.peek()) {
+        Location location = m_locations.peek();
+        switch(location) {
           case TEST:
             m_currentTest.setXmlPackages(m_currentPackages);
             break;
@@ -394,6 +393,8 @@ public class TestNGContentHandler extends DefaultHandler {
             break;
           case CLASS:
             throw new UnsupportedOperationException("CLASS");
+          default:
+            throw new AssertionError("Unexpected value: " + location);
         }
       }
 
@@ -591,7 +592,8 @@ public class TestNGContentHandler extends DefaultHandler {
     }
     else if ("parameter".equals(qName)) {
       String value = expandValue(attributes.getValue("value"));
-      switch(m_locations.peek()) {
+      Location location = m_locations.peek();
+      switch(location) {
         case TEST:
           m_currentTestParameters.put(name, value);
           break;
@@ -604,6 +606,8 @@ public class TestNGContentHandler extends DefaultHandler {
         case INCLUDE:
           m_currentInclude.parameters.put(name, value);
           break;
+        default:
+          throw new AssertionError("Unexpected value: " + location);
       }
     }
   }
@@ -738,9 +742,6 @@ public class TestNGContentHandler extends DefaultHandler {
     else if ("script".equals(qName)) {
       xmlScript(false, null);
     }
-    else if ("packages".equals(qName)) {
-      xmlPackages(false, null);
-    }
     else if ("include".equals(qName)) {
       xmlInclude(false, null);
     } else if ("exclude".equals(qName)){
