@@ -11,9 +11,12 @@ import org.testng.TestNG;
 import org.testng.TestNGException;
 import org.testng.collections.Lists;
 import org.testng.collections.Maps;
+import org.testng.internal.Utils;
 import org.testng.reporters.XMLStringBuffer;
 import org.testng.xml.dom.ParentSetter;
 
+import static org.testng.xml.XmlSuite.ParallelMode.skipDeprecatedValues;
+
 /**
  * This class describes the tag &lt;test&gt;  in testng.xml.
  *
@@ -378,14 +381,17 @@ public class XmlTest implements Serializable, Cloneable {
   }
 
   /**
+   * @deprecated Use {@code getLocalParameters()} instead
+   *
    * @return the parameters defined on this <test> tag only
    */
+  @Deprecated
   public Map<String, String> getTestParameters() {
-    return m_parameters;
+    return getLocalParameters();
   }
 
   public void setParallel(XmlSuite.ParallelMode parallel) {
-    m_parallel = parallel;
+    m_parallel = skipDeprecatedValues(parallel);
   }
 
   public XmlSuite.ParallelMode getParallel() {
